# rst-in-md

`rst-in-md` is a simple tool to convert [reStructuredText](https://docutils.sourceforge.io/rst.html) within [Markdown](https://daringfireball.net/projects/markdown/), built to extend [Python Markdown](https://python-markdown.github.io/).

Check out the [documentation](https://sebpretzer.github.io/rst-in-md/) for more information.
